@@ -1,7 +1,7 @@
 """
 Type annotations for ec2-instance-connect service client.
 
-[Open documentation](./client.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client.html)
 
 Usage::
 
@@ -44,8 +44,8 @@ class Exceptions:
 
 class EC2InstanceConnectClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.86/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client)
-    [Show boto3-stubs documentation](./client.md)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client.html)
     """
 
     meta: ClientMeta
@@ -53,8 +53,8 @@ class EC2InstanceConnectClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.86/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client.html#can_paginate)
         """
 
     def generate_presigned_url(
@@ -65,22 +65,22 @@ class EC2InstanceConnectClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.86/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client.html#generate_presigned_url)
         """
 
     def send_serial_console_ssh_public_key(
-        self, InstanceId: str, SSHPublicKey: str, SerialPort: int = None
+        self, *, InstanceId: str, SSHPublicKey: str, SerialPort: int = None
     ) -> SendSerialConsoleSSHPublicKeyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.86/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.send_serial_console_ssh_public_key)
-        [Show boto3-stubs documentation](./client.md#send_serial_console_ssh_public_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.send_serial_console_ssh_public_key)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client.html#send_serial_console_ssh_public_key)
         """
 
     def send_ssh_public_key(
-        self, InstanceId: str, InstanceOSUser: str, SSHPublicKey: str, AvailabilityZone: str
+        self, *, InstanceId: str, InstanceOSUser: str, SSHPublicKey: str, AvailabilityZone: str
     ) -> SendSSHPublicKeyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.86/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.send_ssh_public_key)
-        [Show boto3-stubs documentation](./client.md#send_ssh_public_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.send_ssh_public_key)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client.html#send_ssh_public_key)
         """
